Index: boost/utility/result_of.hpp
===================================================================
--- boost/utility/result_of.hpp	(revision 77511)
+++ boost/utility/result_of.hpp	(working copy)
@@ -34,6 +34,7 @@
 
 template<typename F> struct result_of;
 template<typename F> struct tr1_result_of; // a TR1-style implementation of result_of
+template<typename F> struct cxx11_result_of; // a decltype-based implementation of result_of
 
 #if !defined(BOOST_NO_SFINAE) && !defined(BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 namespace detail {
@@ -41,7 +42,7 @@
 BOOST_MPL_HAS_XXX_TRAIT_DEF(result_type)
 
 template<typename F, typename FArgs, bool HasResultType> struct tr1_result_of_impl;
-template<typename F> struct cpp0x_result_of_impl;
+template<typename F> struct cxx11_result_of_impl;
 
 template<typename F>
 struct result_of_void_impl
Index: boost/utility/detail/result_of_iterate.hpp
===================================================================
--- boost/utility/detail/result_of_iterate.hpp	(revision 77511)
+++ boost/utility/detail/result_of_iterate.hpp	(working copy)
@@ -33,19 +33,18 @@
             (boost::detail::has_result_type<F>::value)> >::type { };
 #endif
 
-#if !defined(BOOST_NO_DECLTYPE) && defined(BOOST_RESULT_OF_USE_DECLTYPE)
-
+#if !defined(BOOST_NO_DECLTYPE)
 // Uses declval following N3225 20.7.7.6 when F is not a pointer.
 template<typename F BOOST_PP_COMMA_IF(BOOST_PP_ITERATION())
          BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),typename T)>
-struct result_of<F(BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),T))>
+struct cxx11_result_of<F(BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),T))>
     : mpl::if_<
           mpl::or_< is_pointer<F>, is_member_function_pointer<F> >
         , detail::tr1_result_of_impl<
             typename remove_cv<F>::type, 
             typename remove_cv<F>::type(BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),T)), false
           >
-        , detail::cpp0x_result_of_impl<
+        , detail::cxx11_result_of_impl<
               F(BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),T))
           >
       >::type
@@ -55,7 +54,7 @@
 
 template<typename F BOOST_PP_COMMA_IF(BOOST_PP_ITERATION())
          BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),typename T)>
-struct cpp0x_result_of_impl<F(BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),T))>
+struct cxx11_result_of_impl<F(BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),T))>
 {
   typedef decltype(
     boost::declval<F>()(
@@ -65,7 +64,15 @@
 };
 
 } // namespace detail 
+#endif
 
+#if !defined(BOOST_NO_DECLTYPE) && defined(BOOST_RESULT_OF_USE_DECLTYPE)
+
+template<typename F BOOST_PP_COMMA_IF(BOOST_PP_ITERATION())
+         BOOST_PP_ENUM_PARAMS(BOOST_PP_ITERATION(),typename T)>
+struct result_of<F(BOOST_RESULT_OF_ARGS)>
+    : cxx11_result_of<F(BOOST_RESULT_OF_ARGS)> { };
+
 #else // defined(BOOST_NO_DECLTYPE)
 
 #if !BOOST_WORKAROUND(__BORLANDC__, BOOST_TESTED_AT(0x551))
